espei package
=============

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   espei.error_functions
   espei.optimizers
   espei.parameter_selection

Submodules
----------

espei.analysis module
---------------------

.. automodule:: espei.analysis
   :members:
   :undoc-members:
   :show-inheritance:

espei.citing module
-------------------

.. automodule:: espei.citing
   :members:
   :undoc-members:
   :show-inheritance:

espei.core\_utils module
------------------------

.. automodule:: espei.core_utils
   :members:
   :undoc-members:
   :show-inheritance:

espei.database\_utils module
----------------------------

.. automodule:: espei.database_utils
   :members:
   :undoc-members:
   :show-inheritance:

espei.datasets module
---------------------

.. automodule:: espei.datasets
   :members:
   :undoc-members:
   :show-inheritance:

espei.espei\_script module
--------------------------

.. automodule:: espei.espei_script
   :members:
   :undoc-members:
   :show-inheritance:

espei.logger module
-------------------

.. automodule:: espei.logger
   :members:
   :undoc-members:
   :show-inheritance:

espei.paramselect module
------------------------

.. automodule:: espei.paramselect
   :members:
   :undoc-members:
   :show-inheritance:

espei.phase\_models module
--------------------------

.. automodule:: espei.phase_models
   :members:
   :undoc-members:
   :show-inheritance:

espei.plot module
-----------------

.. automodule:: espei.plot
   :members:
   :undoc-members:
   :show-inheritance:

espei.priors module
-------------------

.. automodule:: espei.priors
   :members:
   :undoc-members:
   :show-inheritance:

espei.refdata module
--------------------

.. automodule:: espei.refdata
   :members:
   :undoc-members:
   :show-inheritance:

espei.rstate module
-------------------

.. automodule:: espei.rstate
   :members:
   :undoc-members:
   :show-inheritance:

espei.shadow\_functions module
------------------------------

.. automodule:: espei.shadow_functions
   :members:
   :undoc-members:
   :show-inheritance:

espei.sublattice\_tools module
------------------------------

.. automodule:: espei.sublattice_tools
   :members:
   :undoc-members:
   :show-inheritance:

espei.typing module
-------------------

.. automodule:: espei.typing
   :members:
   :undoc-members:
   :show-inheritance:

espei.utils module
------------------

.. automodule:: espei.utils
   :members:
   :undoc-members:
   :show-inheritance:

espei.validation module
-----------------------

.. automodule:: espei.validation
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: espei
   :members:
   :undoc-members:
   :show-inheritance:
